# 
# Example file for parsing and processing XML
#
import xml.dom.minidom
import sys
import os.path

def updateXML(xmlfile):
  #if not os.path.isdir('./js'):
  #  os.makedirs('./js')

  dirName = os.path.dirname(xmlfile)
  print("dirName: %s"%dirName)
  print("xmlfile: %s"%xmlfile)
  wfName = os.path.splitext(os.path.basename(xmlfile))[0]
  print("wfName:%s"%wfName)

  if not os.path.isdir("%s/.parsevro"%dirName):
        print("%s/.parsevro does not exist.  Please run parsevro."%dirName)
        return

  # use the parse() function to load and parse an XML file
  doc = xml.dom.minidom.parse(xmlfile)

  #doc.writexml(sys.stdout)

  
  # print out the document node and the name of the first child tag
  #print(doc.nodeName)
  #print(doc.firstChild.tagName)
  
  # get a list of XML tags from the document and print each one
  wfItems = doc.getElementsByTagName("workflow-item")
  print("%d workflow-item: " % wfItems.length)

  for wfItem in wfItems:
    typeAttr = wfItem.getAttribute("type")
    #print("type: %s" % typeAttr)
    if typeAttr == "task":
      taskName = wfItem.getAttribute("name")
      print("\ntaskName: %s" % taskName)

      displayNameItem = wfItem.getElementsByTagName("display-name")[0]
      for node in displayNameItem.childNodes:
        displayName = node.data
        print("display-name: %s" % displayName)

      scriptItem = wfItem.getElementsByTagName("script")[0]
      for node in scriptItem.childNodes:
        script = node.data
        #print("\nscript: \n%s" % script)

      fileName = "%s/.parsevro/%s_%s_%s.js" % (dirName, wfName, taskName, displayName)
      print("\Reading contents of fileName: \n%s" % fileName)

      if not os.path.isfile(fileName):
        print("%s does not exist.  Please run parsevro again."%fileName)
        continue
        
      f = open(fileName,"r")
      script = f.read()
      f.close()
      #print("file contents:")
      #print(script)


      scriptItem.childNodes[0].data = script

  f = open("%s"%xmlfile,"w+")
  print("writing %s"%f.name)
  doc.writexml(f)
  f.close()

  # create a new XML tag and add it into the document
#   newSkill = doc.createElement("skill")
#   newSkill.setAttribute("name","jQuery")
#   doc.firstChild.appendChild(newSkill)

def main():
  rootDir = './workflows/src/main/resources/Workflow'
  
  if not os.path.isdir(rootDir):
    print("Looking for XML files in %s"%rootDir)
    print("Are you in the right location?  CD to the top leve of a 'mixed' project that contains the %s sub folder structure."%rootDir)
    exit

  print("Updating XML ...")
  
  for dirName, subdirList, fileList in os.walk(rootDir):
    #print("%s" % dirName)

    if len(fileList) > 0:
      for filename in fileList:
        if filename.endswith(".xml"):
          print("\n***%s"%filename)  
          updateXML(dirName+"/"+filename)



from setuptools import setup, find_packages

# Load the README file.
#with open(file="README.md", mode="r") as readme_handle:
#    long_description = readme_handle.read()
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md')) as f:
    long_description = f.read()

setup(
    name='vroParse',
    author='Jim Sadlek',
    author_email='sadlekj@vmware.com',
    version='0.1.0',
    license='MIT',

    # Here is a small description of the library. This appears
    # when someone searches for the library on https://pypi.org/search.
    description='Parses scriptable tasks out of vRO Workflow XML, saves them as descrete files for editing and SCC, and imports edits in code back into XML.',

    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/nhlpens66/vroParse',
    keywords='sigma coding, governments, finance, APIs',
    packages=find_packages(),
    entry_points={ 
        'console_scripts': [ 
            'parsevro = parsevro.parsevro:main',
            'updatevro = updatevro.updatevro:main'
        ] 
    },

    # I also have some package data, like photos and JSON files, so
    # I want to include those as well.
    include_package_data=False,

    # Here I can specify the python version necessary to run this library.
    python_requires='>=3.7',

    # Additional classifiers that give some characteristics about the package.
    # For a complete list go to https://pypi.org/classifiers/.
    classifiers=[

        # I can say what phase of development my library is in.
        'Development Status :: 3 - Alpha',

        # Here I'll add the audience this library is intended for.
        'Intended Audience :: Developers',
        #'Intended Audience :: CI/CD',
        #'Intended Audience :: DevOps',

        # Here I'll define the license that guides my library.
        'License :: OSI Approved :: MIT License',

        # Here I'll note that package was written in English.
        'Natural Language :: English',

        # Here I'll note that any operating system can use it.
        'Operating System :: OS Independent',

        # Here I'll specify the version of Python it uses.
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',

        # Here are the topics that my library covers.
        #'Topic :: Parse XML',
        #'Topic :: vRealize',
        #'Topic :: VMware'

    ]
)
